function love.load()

	love.mouse.setVisible(false)
	
	love.graphics.setFont(
		love.graphics.newFont("res/gfx/font/edunline.ttf", 64)
	)

	DEBUG = false
	SHADERS = false
	
	if love.graphics.isSupported("canvas", "npot", "pixeleffect") then
	
		SHADERS = true
		
	end
	
	-- default graphics settings for debug
	local width, height = 800, 600
	local fullscreen = false
	local vsync = false
	local fsaa = 0

	-- find the max supported resolution
	local modes = love.graphics.getModes()
	table.sort(modes, function(a, b)
		return (a.width * a.height) < (b.width * b.height)
	end)
	local maxMode = modes[#modes]

	if not DEBUG then
	
		width, height = maxMode.width, maxMode.height
		fullscreen = true
		vsync = false
		fsaa = 4
	
	end
	
	love.graphics.setMode(
		width,
		height,
		fullscreen,
		vsync,
		fsaa
	)

	SCREEN_WIDTH = love.graphics.getWidth()
	SCREEN_HEIGHT = love.graphics.getHeight()

	if SHADERS then
	
		require "src.util.Shaders"
	
	end
	
	-- library requirements
	require "lib.middleclass"
	--require "lib.slam"
	
	-- utility requirements
	require "src.util.Point"
	require "src.util.Vector"
	require "src.util.Camera"
	require "src.util.Colors"
	
	-- core game requirements
	require "src.game.Entity"
	require "src.game.EntityManager"
	require "src.game.Wall"
	require "src.game.PlayerWall"
	require "src.game.KillWall"
	require "src.game.Bullet"
	require "src.game.Enemy"
	require "src.game.Turret"
	require "src.game.Tank"
	require "src.game.Drone"
	require "src.game.Player"
	require "src.game.Tile"
	require "src.game.Wave"
	require "src.game.Game"
	
	instance = Game()
	
end

function love.update(dt)

	instance:update(dt)

end

function love.draw()

	love.graphics.push()
	
	instance:draw()
	
	love.graphics.pop()

end

function love.keypressed(key, unicode)

	if key == "escape" then
		
		instance.world:destroy()
		love.event.quit()
		
	end

end
