DRONE_SHAPE = love.physics.newCircleShape(10)
DRONE_RADIUS = 10

-- Drone class definition

Drone = class("Drone", Enemy)

function Drone:initialize(world, pos, manager)

	Enemy.initialize(self, world, pos, TANK_SHAPE, manager)
	
	self:setHealth(100)

	self.score = 50
	
	self.speed = 200
	self.direction = Vector(0, 0)
	
	self.angle = 0
	self.aim = Vector(0, 0)
	
	self.shootSpeed = 1
	self.shootTimer = 0
	
	self.bulletDamage = 5
	self.bulletSpeed = 400
	
end

function Drone:update(dt)

	Enemy.update(self, dt)
	
	self:gotoPlayer(dt)
	self:handleRotation()
	self:shoot(dt)

end

function Drone:gotoPlayer(dt)

	local playerPos = self.manager:getPlayer().pos
	
	self.direction.x = (playerPos.x - self.pos.x)
	self.direction.y = (playerPos.y - self.pos.y)
	
	self.direction:normalize()
	
	self:setVelocity(Vector(self.direction.x * self.speed, self.direction.y * self.speed))

end

function Drone:handleRotation()

	local playerPos = self.manager:getPlayer().pos
	
	self.angle = (
		math.atan2(playerPos.y - self.pos.y, playerPos.x - self.pos.x) - (math.pi / 2)
	)
	
	self.aim.x = (playerPos.x - self.pos.x)
	self.aim.y = (playerPos.y - self.pos.y)
	
	self.aim:normalize()

end

function Drone:shoot(dt)

	self.shootTimer = self.shootTimer + dt
		
	if self.shootTimer > self.shootSpeed then
		
		-- the bullet needs to spawn outside of the turret hitbox
		local bulletPos = Point(
			self.pos.x + (self.aim.x * 40),
			self.pos.y + (self.aim.y * 40)
		)
		
		self.manager:addEntity(
			Bullet(
				self.manager:getWorld(),
				bulletPos,
				self.aim:getCopy(),
				self.bulletSpeed,
				self.bulletDamage,
				false
			)
		)
		
		self.shootTimer = 0
		
	end 

end

function Drone:draw()

	love.graphics.setColor(COLOR.ENEMY)

	love.graphics.circle("line", self.pos.x, self.pos.y, DRONE_RADIUS, 20)
	
	-- draw rotated head with use of canvases
	love.graphics.push()
	love.graphics.translate(self.pos.x, self.pos.y)
	love.graphics.rotate(self.angle)
	
	-- barrel
	love.graphics.rectangle(
		"line",
		-3,
		11,
		6,
		10
	)
	
	love.graphics.pop()
	
	Enemy.drawHealthBar(self)
	
end