ENTITY_SOUND_HIT = love.audio.newSource("res/sfx/entity_hit.wav")
ENTITY_SOUND_SHOOT = love.audio.newSource("res/sfx/entity_shoot.wav")

-- these groups wills make sure some bodies don't collide with eachother
ENTITY_GROUP_PLAYER = -1
ENTITY_GROUP_ENEMY = -2
ENTITY_GROUP_WALL = -3

-- Entity class definition

Entity = class("Entity")

function Entity:initialize(world, pos, shape, manager)

	self.pos = pos
	
	self.body = love.physics.newBody(world, pos.x, pos.y, "dynamic")
	self.shape = shape
	self.fixture = love.physics.newFixture(self.body, self.shape)

	self.id = 0
	
	self.health = 100
	self.dead = false
	
	-- the entity manager
	self.manager = manager

end

function Entity:update(dt)

	self.pos.x = self.body:getX()
	self.pos.y = self.body:getY()

end

function Entity:draw()

	love.graphics.polygon(
		"line",
		self.body:getWorldPoints(self.shape:getPoints())
	)

end

function Entity:drawHealthBar()

	local barSize = math.floor(self.health / 5)

	local bx = (self.pos.x - (barSize / 2))
	local by = (self.pos.y - 30)

	love.graphics.rectangle(
		"fill",
		bx,
		by,
		barSize,
		4
	)

end

function Entity:getId()

	return self.id

end

function Entity:setId(id)

	self.id = id

end

function Entity:setHealth(health)

	self.health = health

end

function Entity:heal(amount)

	self.health = self.health + amount

end

function Entity:hurt(amount)

	self.health = self.health - amount
	
	if self.health < 0 then
	
		self:kill()
	
	end
	
	ENTITY_SOUND_HIT:stop()
	ENTITY_SOUND_HIT:play()

end

function Entity:kill()

	self.health = 0
	self.dead = true

end

function Entity:isDead()

	return self.dead

end

function Entity:setVelocity(vel)

	self.body:setLinearVelocity(vel.x, vel.y)

end