PLAYER_SHAPE = love.physics.newPolygonShape(
	-5, -5,
	 0, -8,
	 5, -5,
	 0, 10
)

-- Player class definition

Player = class("Player", Entity)

function Player:initialize(world, pos, manager)
	
	-- base class initialize method
	Entity.initialize(self, world, pos, PLAYER_SHAPE, manager)
	
	self:setHealth(1)
	
	-- physics stuff
	self.body:setFixedRotation(true)
	self.fixture:setUserData({
		class = self,
		id = "player"
	})
	self.fixture:setGroupIndex(ENTITY_GROUP_PLAYER)
	
	self.bulletManager = bulletManager
	
	-- movement stuff
	self.angle = 0
	self.speed = 500
	self.aim = Vector(0, 0)
	
	-- shooting stuff
	self.shootSpeed = 0.05
	self.shootTimer = 0
	
	self.bulletDamage = 10
	self.bulletSpeed = 1000
	
	-- score stuff
	self.score = 0
	
	self.shootSound = love.audio.newSource("res/sfx/player_shoot.wav")

end

function Player:update(dt)

	Entity.update(self, dt)

	self:handleRotation()
	self:handleInput(dt)

end

function Player:draw()

	love.graphics.setColor(COLOR.FRIEND)

	Entity.draw(self)
	
	love.graphics.setColor(COLOR.BLACK)
	
	-- print score
	love.graphics.printf(
		self.score,
		15,
		SCREEN_HEIGHT - 68,
		SCREEN_WIDTH,
		"left"
	)
	
end

function Player:handleRotation()

	local mx, my = love.mouse.getPosition()
	
	self.angle = (
		math.atan2(my - self.pos.y, mx - self.pos.x) - (math.pi / 2)
	)
	
	self.aim.x = (mx - self.pos.x)
	self.aim.y = (my - self.pos.y)
	
	self.aim:normalize()
	
	self.body:setAngle(self.angle)

end

function Player:handleInput(dt)
	
	self:move()
	
	if love.mouse.isDown("l") then
	
		self:shoot(dt)
	
	else
	
		self.shootTimer = 0
	
	end

end

function Player:move()

	local vx, vy = self.body:getLinearVelocity()
	
	if love.keyboard.isDown("w") then
	
		self.body:setLinearVelocity(vx, -self.speed)
	
	elseif love.keyboard.isDown("s") then
	
		self.body:setLinearVelocity(vx, self.speed)
	
	else
	
		self.body:setLinearVelocity(vx, 0)
	
	end
	
	vx, vy = self.body:getLinearVelocity()
	
	if love.keyboard.isDown("a") then
	
		self.body:setLinearVelocity(-self.speed, vy)
	
	elseif love.keyboard.isDown("d") then
	
		self.body:setLinearVelocity(self.speed, vy)
	
	else
	
		self.body:setLinearVelocity(0, vy)
	
	end

end

function Player:shoot(dt)

	self.shootTimer = self.shootTimer + dt
		
	if self.shootTimer > self.shootSpeed then
		
		ENTITY_SOUND_SHOOT:stop()
		ENTITY_SOUND_SHOOT:play()
		
		-- the bullet needs to spawn outside of the player hitbox
		local bulletPos = Point(
			self.pos.x + (self.aim.x * 20),
			self.pos.y + (self.aim.y * 20)
		)
		
		self.manager:addEntity(
			Bullet(
				self.manager:getWorld(),
				bulletPos,
				self.aim:getCopy(),
				self.bulletSpeed,
				self.bulletDamage,
				true
			)
		)
		
		self.shootTimer = 0
		
	end

end

function Player:increaseScore(amount)

	self.score = self.score + amount

end