TURRET_SHAPE = love.physics.newRectangleShape(40, 40)

-- Turret class definition

Turret = class("Turret", Enemy)

function Turret:initialize(world, pos, manager)

	Enemy.initialize(self, world, pos, TURRET_SHAPE, manager)
	
	self.score = 100
	
	self:setHealth(75)
	
	self.angle = 0
	self.aim = Vector(0, 0)
	
	self.shootSpeed = 0.5
	self.shootTimer = 0
	
	self.bulletDamage = 5
	self.bulletSpeed = 700

end

function Turret:update(dt)

	Enemy.update(self, dt)
	
	self:handleRotation()
	self:shoot(dt)

end

function Turret:draw()

	Enemy.draw(self)
	
	-- draw rotated head with use of canvases
	love.graphics.push()
	love.graphics.translate(self.pos.x, self.pos.y)
	love.graphics.rotate(self.angle)
	
	-- head base
	love.graphics.rectangle(
		"line",
		-5,
		-5,
		10,
		10
	)
	
	-- head barrel
	love.graphics.rectangle(
		"line",
		-3,
		5,
		6,
		25
	)
	
	love.graphics.pop()

end

function Turret:handleRotation()

	local playerPos = self.manager:getPlayer().pos
	
	self.angle = (
		math.atan2(playerPos.y - self.pos.y, playerPos.x - self.pos.x) - (math.pi / 2)
	)
	
	self.aim.x = (playerPos.x - self.pos.x)
	self.aim.y = (playerPos.y - self.pos.y)
	
	self.aim:normalize()

end

function Turret:shoot(dt)

	self.shootTimer = self.shootTimer + dt
		
	if self.shootTimer > self.shootSpeed then
		
		-- the bullet needs to spawn outside of the turret hitbox
		local bulletPos = Point(
			self.pos.x + (self.aim.x * 40),
			self.pos.y + (self.aim.y * 40)
		)
		
		self.manager:addEntity(
			Bullet(
				self.manager:getWorld(),
				bulletPos,
				self.aim:getCopy(),
				self.bulletSpeed,
				self.bulletDamage,
				false
			)
		)
		
		self.shootTimer = 0
		
	end 

end